@@ -1,16 +1,16 @@
 // -*- Mode: C++ ; indent-tabs-mode: t -*-
 /* This file is part of Patchage.
  * Copyright (C) 2008 Nedko Arnaudov <nedko@arnaudov.name>
- * 
+ *
  * Patchage is free software; you can redistribute it and/or modify it under the
  * terms of the GNU General Public License as published by the Free Software
  * Foundation; either version 2 of the License, or (at your option) any later
  * version.
- * 
+ *
  * Patchage is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
@@ -22,7 +22,7 @@
 #include <set>
 #include <iostream>
 
-#include CONFIG_H_PATH
+#include "patchage-config.h"
 
 #include <glib.h>
 #include <dbus/dbus.h>
@@ -30,7 +30,7 @@
 #include <dbus/dbus-glib-lowlevel.h>
 
 #include <boost/format.hpp>
-#include <raul/SharedPtr.hpp>
+#include "raul/SharedPtr.hpp"
 
 #include "PatchageCanvas.hpp"
 #include "PatchageEvent.hpp"
@@ -67,8 +67,8 @@ JackDriver::JackDriver(Patchage* app)
 	: Driver(128)
 	, _app(app)
 	, _dbus_connection(0)
-	, _server_started(false)
 	, _server_responding(false)
+	, _server_started(false)
 	, _graph_version(0)
 	, _max_dsp_load(0.0)
 {
@@ -91,7 +91,7 @@ JackDriver::~JackDriver()
 /** Destroy all JACK (canvas) ports.
  */
 void
-JackDriver::destroy_all_ports()
+JackDriver::destroy_all()
 {
 	ItemList modules = _app->canvas()->items(); // copy
 	for (ItemList::iterator m = modules.begin(); m != modules.end(); ++m) {
@@ -102,7 +102,7 @@ JackDriver::destroy_all_ports()
 		PortVector ports = module->ports(); // copy
 		for (PortVector::iterator p = ports.begin(); p != ports.end(); ++p) {
 			boost::shared_ptr<PatchagePort> port = boost::dynamic_pointer_cast<PatchagePort>(*p);
-			if (port && port->type() == JACK_AUDIO || port->type() == JACK_MIDI) {
+			if (port && (port->type() == JACK_AUDIO || port->type() == JACK_MIDI)) {
 				module->remove_port(port);
 				port->hide();
 			}
@@ -111,7 +111,7 @@ JackDriver::destroy_all_ports()
 		if (module->ports().empty())
 			_app->canvas()->remove_item(module);
 		else
-			module->resize();
+			_app->enqueue_resize(module);
 	}
 }
 
@@ -474,7 +474,7 @@ JackDriver::stop_server()
 	}
 
 	dbus_message_unref(reply_ptr);
-	
+
 	if (!_server_started) {
 		_server_started = false;
 		signal_detached.emit();
@@ -555,7 +555,7 @@ JackDriver::add_port(
 				is_input,
 				_app->state_manager()->get_port_color(type))));
 
-	module->resize();
+	_app->enqueue_resize(module);
 }
 
 
@@ -614,13 +614,13 @@ JackDriver::remove_port(
 
 	module->remove_port(port);
 	port.reset();
-			
+
 	// No empty modules (for now)
 	if (module->num_ports() == 0) {
 		_app->canvas()->remove_item(module);
 		module.reset();
 	} else {
-		module->resize();
+		_app->enqueue_resize(module);
 	}
 
 	if (_app->canvas()->items().empty()) {
@@ -711,7 +711,6 @@ JackDriver::refresh_internal(bool force)
 {
 	DBusMessage* reply_ptr;
 	DBusMessageIter iter;
-	int type;
 	dbus_uint64_t version;
 	const char * reply_signature;
 	DBusMessageIter clients_array_iter;
@@ -760,7 +759,7 @@ JackDriver::refresh_internal(bool force)
 		goto unref;
 	}
 
-	destroy_all_ports();
+	destroy_all();
 
 	//info_msg(str(boost::format("got new graph version %llu") % version));
 	_graph_version = version;
@@ -976,6 +975,8 @@ JackDriver::set_buffer_size(jack_nframes_t size)
 	}
 
 	dbus_message_unref(reply_ptr);
+
+	return true;
 }
 
 
@@ -1128,7 +1129,7 @@ JackDriver::rewind_transport()
 
 
 boost::shared_ptr<PatchagePort>
-JackDriver::find_port_view(Patchage* patchage, const PatchageEvent::PortRef& ref)
+JackDriver::find_port_view(Patchage* patchage, const PortID& id)
 {
 	assert(false);  // we dont use events at all
 }
@@ -1137,7 +1138,7 @@ JackDriver::find_port_view(Patchage* patchage, const PatchageEvent::PortRef& ref
 boost::shared_ptr<PatchagePort>
 JackDriver::create_port_view(
 	Patchage * patchage,
-	const PatchageEvent::PortRef& ref)
+	const PortID& id)
 {
 	assert(false);  // we dont use events at all
 }
@@ -1147,7 +1148,7 @@ void
 JackDriver::error_msg(const std::string& msg) const
 {
 #if defined(LOG_TO_STATUS)
-	_app->status_message((std::string)"[JACKDBUS] " + msg);
+	_app->status_msg((std::string)"[JACKDBUS] " + msg);
 #endif
 
 #if defined(LOG_TO_STD)
@@ -1160,7 +1161,7 @@ void
 JackDriver::info_msg(const std::string& msg) const
 {
 #if defined(LOG_TO_STATUS)
-	_app->status_message((std::string)"[JACKDBUS] " + msg);
+	_app->status_msg((std::string)"[JACKDBUS] " + msg);
 #endif
 
 #if defined(LOG_TO_STD)
