@@ -1,6 +1,6 @@
 /* This file is part of Patchage
- * Copyright (C) 2007 Dave Robillard <http://drobilla.net>
- * 
+ * Copyright (C) 2007-2009 Dave Robillard <http://drobilla.net>
+ *
  * Patchage is free software: you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free
  * Software Foundation, either version 3 of the License, or (at your option)
@@ -20,6 +20,7 @@
 
 #include <string>
 #include <boost/utility.hpp>
+#include <libglademm/xml.h>
 
 template <typename W>
 class Widget : public boost::noncopyable {
@@ -40,6 +41,6 @@ public:
 private:
 	W* _me;
 };
-	
+
 
 #endif // PATCHAGE_WIDGET_HPP
